Chess constructor
Chess()
By default start with the standard chess starting position
Implementation
Chess() {
load(DEFAULT_POSITION, true);
}
By default start with the standard chess starting position
Chess() {
load(DEFAULT_POSITION, true);
}